<?php

require_once 'HTML/QuickForm.php';
require_once 'HTML/QuickForm/advmultiselect.php';

$form = new HTML_QuickForm('multiselect7');

$fruit_styles = array(
    'class' => 'icons',
    'onmouseover' => "this.className='over'",
    'onmouseout'  => "this.className='icons'"
);
$pear  = array_merge($fruit_styles, array('disabled' => 'disabled'));
$lemon = array_merge($fruit_styles,
                     array('class' => 'goldstar',
                           'onmouseout'  => "this.className='goldstar'"
));
$tangerine = array_merge($fruit_styles,
                         array('style' => 'background-color:yellow; color:black;')
);

$fruit_array = array(
    'apple'     =>  array('Apple', $fruit_styles),
    'orange'    =>  array('Orange', $fruit_styles),
    'pear'      =>  array('Pear', $pear),
    'banana'    =>  array('Banana', $fruit_styles),
    'cherry'    =>  array('Cherry', $fruit_styles),
    'kiwi'      =>  array('Kiwi', $fruit_styles),
    'lemon'     =>  array('Lemon', $lemon),
    'lime'      =>  array('Lime', $fruit_styles),
    'tangerine' =>  array('Tangerine', $tangerine),
);

// rendering with QF renderer engine and template system
$form->addElement('header', null, 'Advanced Multiple Select: custom layout ');

$form->addElement('text', 'name', 'Name:', array('size' => 40, 'maxlength' => 80));

$pool =& $form->addElement('advmultiselect', 'fruit', null, null,
                           array('class' => 'pool')
);
foreach ($fruit_array as $key => $data) {
    if (!is_array($data)) {
        $data = array($data);
    }
    $attr = isset($data[1]) ? $data[1] : null;
    $pool->addOption($data[0], $key, $attr);
}

$pool->setLabel(array('Fruit:', 'Available', 'Selected'));

$template2 = '
<table{class}>
<!-- BEGIN label_2 --><tr><th>{label_2}</th><!-- END label_2 -->
<!-- BEGIN label_3 --><th>&nbsp;</th><th>{label_3}</th></tr><!-- END label_3 -->
<tr>
  <td align="center">{unselected}</td>
  <td align="center">{add}{remove}</td>
  <td align="center">{selected}</td>
</tr>
</table>
';
$template1 = '
<table{class}>
<!-- BEGIN label_3 --><tr><th>{label_3}</th></tr><!-- END label_3 -->
<tr>
  <td>{selected}</td>
</tr>
</table>
';

if (isset($_POST['multiselect'])) {
    $pool->setElementTemplate($template2);
} else {
    $pool->setElementTemplate($template1);
}

if ($_SERVER['REQUEST_METHOD'] == 'GET') {
    $form->setDefaults(array('fruit' => array('kiwi','lime')));

} elseif (isset($_POST['fruit'])) {
    $form->setDefaults(array('fruit' => $_POST['fruit']));
}

//$form->addElement('submit', 'send', 'Send');
$buttons[] =& $form->createElement('submit', null, 'Submit');
$buttons[] =& $form->createElement('reset', null, 'Reset');
$buttons[] =& $form->createElement('checkbox', 'multiselect', null, 'use dual select boxes layout');
$form->addGroup($buttons);

$form->addRule('name', 'Your name is required', 'required');
$form->addRule('fruit', 'At least one fruit is required', 'required');

$form->applyFilter('__ALL__', 'trim');
$form->applyFilter('__ALL__', 'strip_tags');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
    "http://www.w3c.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
<title>HTML_QuickForm::advMultiSelect example 7</title>
<style type="text/css">
<!--
body {
  background-color: #FFF;
  font-family: Verdana, Arial, helvetica;
  font-size: 10pt;
}

table.pool {
  border: 0;
  background-color: lightyellow;
}
table.pool th {
  font-size: 80%;
  font-style: italic;
  text-align: center;
}

.inputCommand {
    background-color: #d0d0d0;
    border: 1px solid #7B7B88;
    width: 7em;
    margin-bottom: 2px;
}

<?php
if (!isset($_POST['multiselect'])) {
    echo $pool->getElementCss();

    echo '
label input {
  margin-right: 16px;
}
label.bluestar, label.goldstar {
  background-repeat: no-repeat;
  background-position: 20px center;
}
label.bluestar{
  background-image: url(bluestar-12.gif) ;
}
label.goldstar {
  background-image: url(goldstar-12.gif) ;
}

label.over {
  background-color: #0a246a;
  color: #fff;
}
';
}
?>

// -->
</style>

<?php
if (isset($_POST['multiselect'])) {
    echo $pool->getElementJs(false);
}
?>

</head>
<body>
<?php
if ($form->validate()) {
    $clean = $form->getSubmitValues();

    echo '<pre>';
    print_r($clean);
    echo '</pre>';

    printf("<p>Welcome <b>%s</b> you've selected these fruits:</p>", $clean['name']);
    echo implode(', ', $clean['fruit']);
}
$form->display();
?>
</body>
</html>